==> org.apache.felix.http.base-4.2.0-source-release.tar.gz: org.apache.felix.http.base-4.2.0/src/main/java/org/apache/felix/http/base/internal/context/ExtServletContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.felix.http.base.internal.context;

import java.io.IOException;

import javax.servlet.ServletContext;
import javax.servlet.ServletRequestAttributeListener;
import javax.servlet.ServletRequestListener;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSessionAttributeListener;
import javax.servlet.http.HttpSessionListener;

import org.apache.felix.http.base.internal.HttpConfig;

public interface ExtServletContext extends ServletContext
{
    boolean handleSecurity(HttpServletRequest req, HttpServletResponse res) throws IOException;

    void finishSecurity(HttpServletRequest req, HttpServletResponse res);

    HttpSessionAttributeListener getHttpSessionAttributeListener();

    HttpSessionListener getHttpSessionListener();

    ServletRequestListener getServletRequestListener();

    ServletRequestAttributeListener getServletRequestAttributeListener();

    HttpConfig getConfig();
}

==> org.apache.felix.http.base-5.0.2-source-release.tar.gz: org.apache.felix.http.base-5.0.2/src/main/java/org/apache/felix/http/base/internal/context/ExtServletContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.felix.http.base.internal.context;

import java.io.IOException;

import org.apache.felix.http.base.internal.HttpConfig;

import jakarta.servlet.ServletContext;
import jakarta.servlet.ServletRequestAttributeListener;
import jakarta.servlet.ServletRequestListener;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.servlet.http.HttpSessionAttributeListener;
import jakarta.servlet.http.HttpSessionListener;

/**
 * Internal extension of the servlet context
 */
public interface ExtServletContext extends ServletContext
{
    boolean handleSecurity(HttpServletRequest req, HttpServletResponse res) throws IOException;

    void finishSecurity(HttpServletRequest req, HttpServletResponse res);

    HttpSessionAttributeListener getHttpSessionAttributeListener();

    HttpSessionListener getHttpSessionListener();

    ServletRequestListener getServletRequestListener();

    ServletRequestAttributeListener getServletRequestAttributeListener();

    HttpConfig getConfig();
}
